---
name: Work item
about: New work item for Ape team
labels: 'backlog'

---

### Elevator pitch:
<!-- 1-2 line summary of the scope of this work item -->

### Value:
<!--
  Who is this for?
  Persona or group of people whom will derive value from the scenario.
  What benefits will be achieved or business metrics improved?
-->

### Dependencies:
<!-- Call out key people, teams, tech dependencies, or assumptions. -->

### Design approach:
<!--
  Free text / diagram / whiteboard picture / etc. that clearly shows your approach and considerations to build the task list.
  Existing code patterns in production code base that you will base your work off of.
-->

### Task list:
<!-- Bulleted list describing the exit criteria, desired end state and any documentation, monitors, work for DRI, etc. that will need to be added to make sure someone else can support once it's live. -->
* [ ] Tasks go here

### Estimated completion date:


### Design review:
<!-- 1-2 people needed for signoff -->
Do not signoff unless:
- 1) agreed the tasks and design approach will achieve acceptance, and
- 2) the work can be completed by one person within the SLA.
Design reviewers should consider simpler approaches to achieve goals.

(Please leave a comment to sign off)
